@@ -3,7 +3,7 @@ use strict;
 use Exporter qw'import';
 use Text::Unidecode;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our @EXPORT = (qw(clean_fragment));
 
 =head1 NAME
@@ -29,7 +29,7 @@ This module downgrades strings of text to match
 
 or, to be more exact
 
-  /^([A-Za-z0-9]([-._A-Za-z0-9]*[A-Za-z0-9])?$/
+  /^([-.A-Za-z0-9]([-._A-Za-z0-9]*[-.A-Za-z0-9])?)?$/
 
 This makes the return values safe to be used as URL fragments
 or as file names on many file systems where whitespace
@@ -135,7 +135,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2012-2019 by Max Maischein C<corion@cpan.org>.
+Copyright 2012-2022 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
